@@ -25,13 +25,13 @@ import re
 
 from alembic.migration import MigrationContext
 from alembic.operations import Operations
+import debtcollector.removals
 from oslo_utils import timeutils
 import sqlalchemy
 from sqlalchemy import Boolean
 from sqlalchemy import CheckConstraint
 from sqlalchemy import Column
 from sqlalchemy.engine import Connectable
-from sqlalchemy.engine import reflection
 from sqlalchemy.engine import url as sa_url
 from sqlalchemy import exc
 from sqlalchemy import func
@@ -441,8 +441,7 @@ def get_table(engine, name):
        with ForeignKey creation.
     """
     metadata = MetaData()
-    metadata.bind = engine
-    return Table(name, metadata, autoload=True)
+    return Table(name, metadata, autoload_with=engine)
 
 
 def _get_not_supported_column(col_name_col_instance, column_name):
@@ -476,17 +475,20 @@ def drop_old_duplicate_entries_from_table(engine, table_name,
     :param uc_column_names: Unique constraint columns
     """
     meta = MetaData()
-    meta.bind = engine
 
-    table = Table(table_name, meta, autoload=True)
+    table = Table(table_name, meta, autoload_with=engine)
     columns_for_group_by = [table.c[name] for name in uc_column_names]
 
     columns_for_select = [func.max(table.c.id)]
     columns_for_select.extend(columns_for_group_by)
 
     duplicated_rows_select = sqlalchemy.sql.select(
-        columns_for_select, group_by=columns_for_group_by,
-        having=func.count(table.c.id) > 1)
+        *columns_for_select,
+    ).group_by(
+        *columns_for_group_by
+    ).having(
+        func.count(table.c.id) > 1
+    )
 
     for row in engine.execute(duplicated_rows_select).fetchall():
         # NOTE(boris-42): Do not remove row that has the biggest ID.
@@ -497,7 +499,8 @@ def drop_old_duplicate_entries_from_table(engine, table_name,
             delete_condition &= table.c[name] == row[name]
 
         rows_to_delete_select = sqlalchemy.sql.select(
-            [table.c.id]).where(delete_condition)
+            table.c.id,
+        ).where(delete_condition)
         for row in engine.execute(rows_to_delete_select).fetchall():
             LOG.info("Deleting duplicated row with id: %(id)s from table: "
                      "%(table)s", dict(id=row[0], table=table_name))
@@ -545,6 +548,12 @@ def _restore_indexes_on_deleted_columns(engine, table_name, indexes):
         new_index.create(engine)
 
 
+@debtcollector.removals.remove(
+    message='This API is intended for use with sqlalchemy-migrate, support '
+    'for which is deprecated for removal; it will be removed in a future '
+    'release',
+    version='10.1.0',
+)
 def change_deleted_column_type_to_boolean(engine, table_name,
                                           **col_name_col_instance):
     if engine.name == "sqlite":
@@ -554,15 +563,24 @@ def change_deleted_column_type_to_boolean(engine, table_name,
     table = get_table(engine, table_name)
 
     old_deleted = Column('old_deleted', Boolean, default=False)
-    old_deleted.create(table, populate_default=False)
+    table.metadata.bind = engine
+    try:
+        old_deleted.create(table, populate_default=False)
+    finally:
+        table.metadata.bind = None
 
-    table.update().\
-        where(table.c.deleted == table.c.id).\
-        values(old_deleted=True).\
-        execute()
+    engine.execute(
+        table.update().
+        where(table.c.deleted == table.c.id).
+        values(old_deleted=True)
+    )
 
-    table.c.deleted.drop()
-    table.c.old_deleted.alter(name="deleted")
+    table.metadata.bind = engine
+    try:
+        table.c.deleted.drop()
+        table.c.old_deleted.alter(name="deleted")
+    finally:
+        table.metadata.bind = None
 
     _restore_indexes_on_deleted_columns(engine, table_name, indexes)
 
@@ -578,17 +596,21 @@ def _change_deleted_column_type_to_boolean_sqlite(engine, table_name,
                 column_copy = _get_not_supported_column(col_name_col_instance,
                                                         column.name)
             else:
-                column_copy = column.copy()
+                # FIXME(stephenfin): We shouldn't be using this private API;
+                # figure out how else to copy an arbitrary column schema
+                column_copy = column._copy()
         else:
             column_copy = Column('deleted', Boolean, default=0)
         columns.append(column_copy)
 
-    constraints = [constraint.copy() for constraint in table.constraints]
+    # FIXME(stephenfin): We shouldn't be using this private API;
+    # figure out how else to copy an arbitrary column schema
+    constraints = [constraint._copy() for constraint in table.constraints]
 
     meta = table.metadata
     new_table = Table(table_name + "__tmp__", meta,
                       *(columns + constraints))
-    new_table.create()
+    new_table.create(engine)
 
     indexes = []
     for index in get_indexes(engine, table_name):
@@ -603,17 +625,29 @@ def _change_deleted_column_type_to_boolean_sqlite(engine, table_name,
         else:
             c_select.append(table.c.deleted == table.c.id)
 
-    table.drop()
+    table.drop(engine)
     for index in indexes:
         index.create(engine)
 
-    new_table.rename(table_name)
-    new_table.update().\
-        where(new_table.c.deleted == new_table.c.id).\
-        values(deleted=True).\
-        execute()
+    table.metadata.bind = engine
+    try:
+        new_table.rename(table_name)
+    finally:
+        table.metadata.bind = None
+
+    engine.execute(
+        new_table.update().
+        where(new_table.c.deleted == new_table.c.id).
+        values(deleted=True)
+    )
 
 
+@debtcollector.removals.remove(
+    message='This API is intended for use with sqlalchemy-migrate, support '
+    'for which is deprecated for removal; it will be removed in a future '
+    'release',
+    version='10.1.0',
+)
 def change_deleted_column_type_to_id_type(engine, table_name,
                                           **col_name_col_instance):
     if engine.name == "sqlite":
@@ -624,15 +658,24 @@ def change_deleted_column_type_to_id_type(engine, table_name,
 
     new_deleted = Column('new_deleted', table.c.id.type,
                          default=_get_default_deleted_value(table))
-    new_deleted.create(table, populate_default=True)
+    table.metadata.bind = engine
+    try:
+        new_deleted.create(table, populate_default=True)
+    finally:
+        table.metadata.bind = None
 
     deleted = True  # workaround for pyflakes
-    table.update().\
-        where(table.c.deleted == deleted).\
-        values(new_deleted=table.c.id).\
-        execute()
-    table.c.deleted.drop()
-    table.c.new_deleted.alter(name="deleted")
+    engine.execute(
+        table.update().
+        where(table.c.deleted == deleted).
+        values(new_deleted=table.c.id)
+    )
+    table.metadata.bind = engine
+    try:
+        table.c.deleted.drop()
+        table.c.new_deleted.alter(name="deleted")
+    finally:
+        table.metadata.bind = None
 
     _restore_indexes_on_deleted_columns(engine, table_name, indexes)
 
@@ -652,17 +695,17 @@ def _is_deleted_column_constraint(constraint):
 
 def _change_deleted_column_type_to_id_type_sqlite(engine, table_name,
                                                   **col_name_col_instance):
-    # NOTE(boris-42): sqlaclhemy-migrate can't drop column with check
-    #                 constraints in sqlite DB and our `deleted` column has
-    #                 2 check constraints. So there is only one way to remove
-    #                 these constraints:
-    #                 1) Create new table with the same columns, constraints
-    #                 and indexes. (except deleted column).
-    #                 2) Copy all data from old to new table.
-    #                 3) Drop old table.
-    #                 4) Rename new table to old table name.
-    meta = MetaData(bind=engine)
-    table = Table(table_name, meta, autoload=True)
+    # NOTE(boris-42): sqlalchemy-migrate can't drop column with check
+    # constraints in sqlite DB and our `deleted` column has two check
+    # constraints. There is only one way to remove these constraints:
+    #
+    # 1) Create new table with the same columns, constraints and indexes.
+    #    (except deleted column).
+    # 2) Copy all data from old to new table.
+    # 3) Drop old table.
+    # 4) Rename new table to old table name.
+    meta = MetaData()
+    table = Table(table_name, meta, autoload_with=engine)
     default_deleted_value = _get_default_deleted_value(table)
 
     columns = []
@@ -673,7 +716,9 @@ def _change_deleted_column_type_to_id_type_sqlite(engine, table_name,
                 column_copy = _get_not_supported_column(col_name_col_instance,
                                                         column.name)
             else:
-                column_copy = column.copy()
+                # FIXME(stephenfin): We shouldn't be using this private API;
+                # figure out how else to copy an arbitrary column schema
+                column_copy = column._copy()
         else:
             column_copy = Column('deleted', table.c.id.type,
                                  default=default_deleted_value)
@@ -682,11 +727,13 @@ def _change_deleted_column_type_to_id_type_sqlite(engine, table_name,
     constraints = []
     for constraint in table.constraints:
         if not _is_deleted_column_constraint(constraint):
-            constraints.append(constraint.copy())
+            # FIXME(stephenfin): We shouldn't be using this private API;
+            # figure out how else to copy an arbitrary constraint schema
+            constraints.append(constraint._copy())
 
     new_table = Table(table_name + "__tmp__", meta,
                       *(columns + constraints))
-    new_table.create()
+    new_table.create(engine)
 
     indexes = []
     for index in get_indexes(engine, table_name):
@@ -694,23 +741,30 @@ def _change_deleted_column_type_to_id_type_sqlite(engine, table_name,
         indexes.append(Index(index["name"], *column_names,
                              unique=index["unique"]))
 
-    table.drop()
+    table.drop(engine)
     for index in indexes:
         index.create(engine)
 
-    new_table.rename(table_name)
+    new_table.metadata.bind = engine
+    try:
+        new_table.rename(table_name)
+    finally:
+        new_table.metadata.bind = None
+
     deleted = True  # workaround for pyflakes
-    new_table.update().\
-        where(new_table.c.deleted == deleted).\
-        values(deleted=new_table.c.id).\
-        execute()
+    engine.execute(
+        new_table.update().
+        where(new_table.c.deleted == deleted).
+        values(deleted=new_table.c.id)
+    )
 
     # NOTE(boris-42): Fix value of deleted column: False -> "" or 0.
     deleted = False  # workaround for pyflakes
-    new_table.update().\
-        where(new_table.c.deleted == deleted).\
-        values(deleted=default_deleted_value).\
-        execute()
+    engine.execute(
+        new_table.update().
+        where(new_table.c.deleted == deleted).
+        values(deleted=default_deleted_value)
+    )
 
 
 def get_db_connection_info(conn_pieces):
@@ -734,7 +788,7 @@ def get_indexes(engine, table_name):
     :param table_name: name of the table
     """
 
-    inspector = reflection.Inspector.from_engine(engine)
+    inspector = sqlalchemy.inspect(engine)
     indexes = inspector.get_indexes(table_name)
     return indexes
 
@@ -779,7 +833,7 @@ def add_index(engine, table_name, index_name, idx_columns):
         index = Index(
             index_name, *[getattr(table.c, col) for col in idx_columns]
         )
-        index.create()
+        index.create(engine)
     else:
         raise ValueError("Index '%s' already exists!" % index_name)
 
@@ -794,7 +848,7 @@ def drop_index(engine, table_name, index_name):
     table = get_table(engine, table_name)
     for index in table.indexes:
         if index.name == index_name:
-            index.drop()
+            index.drop(engine)
             break
     else:
         raise ValueError("Index '%s' not found!" % index_name)
