@@ -18,18 +18,19 @@ import contextlib
 import itertools
 from unittest import mock
 
-from oslotest import base as oslo_test_base
 import sqlalchemy as sqla
 from sqlalchemy.engine import url as sqla_url
 from sqlalchemy import event
 import sqlalchemy.exc
-from sqlalchemy.ext.declarative import declarative_base
+from sqlalchemy.orm import declarative_base
 from sqlalchemy.orm import mapper
+from sqlalchemy import sql
 
 from oslo_db import exception
 from oslo_db.sqlalchemy import engines
 from oslo_db.sqlalchemy import exc_filters
-from oslo_db.tests.sqlalchemy import base as test_base
+from oslo_db.tests import base as test_base
+from oslo_db.tests.sqlalchemy import base as db_test_base
 from oslo_db.tests import utils as test_utils
 
 _TABLE_NAME = '__tmp__test__tmp__'
@@ -68,7 +69,7 @@ class _SQLAExceptionMatcher(object):
                 self.assertEqual(sql, exc.statement)
 
 
-class TestsExceptionFilter(_SQLAExceptionMatcher, oslo_test_base.BaseTestCase):
+class TestsExceptionFilter(_SQLAExceptionMatcher, test_base.BaseTestCase):
 
     class Error(Exception):
         """DBAPI base error.
@@ -157,7 +158,7 @@ class TestsExceptionFilter(_SQLAExceptionMatcher, oslo_test_base.BaseTestCase):
         with self._fixture(dialect_name, raises, is_disconnect=is_disconnect):
             with self.engine.connect() as conn:
                 matched = self.assertRaises(
-                    expected, conn.execute, statement, params
+                    expected, conn.execute, sql.text(statement), params
                 )
                 return matched
 
@@ -245,13 +246,14 @@ class TestFallthroughsAndNonDBAPI(TestsExceptionFilter):
 
 
 class TestNonExistentConstraint(
-        _SQLAExceptionMatcher,
-        test_base._DbTestCase):
+    _SQLAExceptionMatcher,
+    db_test_base._DbTestCase,
+):
 
     def setUp(self):
         super(TestNonExistentConstraint, self).setUp()
 
-        meta = sqla.MetaData(bind=self.engine)
+        meta = sqla.MetaData()
 
         self.table_1 = sqla.Table(
             "resource_foo", meta,
@@ -259,12 +261,13 @@ class TestNonExistentConstraint(
             mysql_engine='InnoDB',
             mysql_charset='utf8',
         )
-        self.table_1.create()
+        self.table_1.create(self.engine)
 
 
 class TestNonExistentConstraintPostgreSQL(
-        TestNonExistentConstraint,
-        test_base._PostgreSQLOpportunisticTestCase):
+    TestNonExistentConstraint,
+    db_test_base._PostgreSQLOpportunisticTestCase,
+):
 
     def test_raise(self):
         matched = self.assertRaises(
@@ -287,8 +290,9 @@ class TestNonExistentConstraintPostgreSQL(
 
 
 class TestNonExistentConstraintMySQL(
-        TestNonExistentConstraint,
-        test_base._MySQLOpportunisticTestCase):
+    TestNonExistentConstraint,
+    db_test_base._MySQLOpportunisticTestCase,
+):
 
     def test_raise(self):
         matched = self.assertRaises(
@@ -311,13 +315,14 @@ class TestNonExistentConstraintMySQL(
 
 
 class TestNonExistentTable(
-        _SQLAExceptionMatcher,
-        test_base._DbTestCase):
+    _SQLAExceptionMatcher,
+    db_test_base._DbTestCase,
+):
 
     def setUp(self):
         super(TestNonExistentTable, self).setUp()
 
-        self.meta = sqla.MetaData(bind=self.engine)
+        self.meta = sqla.MetaData()
 
         self.table_1 = sqla.Table(
             "foo", self.meta,
@@ -342,8 +347,9 @@ class TestNonExistentTable(
 
 
 class TestNonExistentTablePostgreSQL(
-        TestNonExistentTable,
-        test_base._PostgreSQLOpportunisticTestCase):
+    TestNonExistentTable,
+    db_test_base._PostgreSQLOpportunisticTestCase,
+):
 
     def test_raise(self):
         matched = self.assertRaises(
@@ -361,8 +367,9 @@ class TestNonExistentTablePostgreSQL(
 
 
 class TestNonExistentTableMySQL(
-        TestNonExistentTable,
-        test_base._MySQLOpportunisticTestCase):
+    TestNonExistentTable,
+    db_test_base._MySQLOpportunisticTestCase,
+):
 
     def test_raise(self):
         matched = self.assertRaises(
@@ -379,8 +386,9 @@ class TestNonExistentTableMySQL(
 
 
 class TestNonExistentDatabase(
-        _SQLAExceptionMatcher,
-        test_base._DbTestCase):
+    _SQLAExceptionMatcher,
+    db_test_base._DbTestCase,
+):
 
     def setUp(self):
         super(TestNonExistentDatabase, self).setUp()
@@ -413,8 +421,9 @@ class TestNonExistentDatabase(
 
 
 class TestNonExistentDatabaseMySQL(
-        TestNonExistentDatabase,
-        test_base._MySQLOpportunisticTestCase):
+    TestNonExistentDatabase,
+    db_test_base._MySQLOpportunisticTestCase,
+):
 
     def test_raise(self):
         matched = self.assertRaises(
@@ -432,8 +441,9 @@ class TestNonExistentDatabaseMySQL(
 
 
 class TestNonExistentDatabasePostgreSQL(
-        TestNonExistentDatabase,
-        test_base._PostgreSQLOpportunisticTestCase):
+    TestNonExistentDatabase,
+    db_test_base._PostgreSQLOpportunisticTestCase,
+):
 
     def test_raise(self):
         matched = self.assertRaises(
@@ -449,12 +459,14 @@ class TestNonExistentDatabasePostgreSQL(
         )
 
 
-class TestReferenceErrorSQLite(_SQLAExceptionMatcher, test_base._DbTestCase):
+class TestReferenceErrorSQLite(
+    _SQLAExceptionMatcher, db_test_base._DbTestCase,
+):
 
     def setUp(self):
         super(TestReferenceErrorSQLite, self).setUp()
 
-        meta = sqla.MetaData(bind=self.engine)
+        meta = sqla.MetaData()
 
         self.table_1 = sqla.Table(
             "resource_foo", meta,
@@ -463,7 +475,7 @@ class TestReferenceErrorSQLite(_SQLAExceptionMatcher, test_base._DbTestCase):
             mysql_engine='InnoDB',
             mysql_charset='utf8',
         )
-        self.table_1.create()
+        self.table_1.create(self.engine)
 
         self.table_2 = sqla.Table(
             "resource_entity", meta,
@@ -473,15 +485,15 @@ class TestReferenceErrorSQLite(_SQLAExceptionMatcher, test_base._DbTestCase):
             mysql_engine='InnoDB',
             mysql_charset='utf8',
         )
-        self.table_2.create()
+        self.table_2.create(self.engine)
 
     def test_raise(self):
-        self.engine.execute("PRAGMA foreign_keys = ON;")
+        self.engine.execute(sql.text("PRAGMA foreign_keys = ON"))
 
         matched = self.assertRaises(
             exception.DBReferenceError,
             self.engine.execute,
-            self.table_2.insert({'id': 1, 'foo_id': 2})
+            self.table_2.insert().values(id=1, foo_id=2)
         )
 
         self.assertInnerException(
@@ -498,11 +510,11 @@ class TestReferenceErrorSQLite(_SQLAExceptionMatcher, test_base._DbTestCase):
         self.assertIsNone(matched.key_table)
 
     def test_raise_delete(self):
-        self.engine.execute("PRAGMA foreign_keys = ON;")
+        self.engine.execute(sql.text("PRAGMA foreign_keys = ON"))
 
         with self.engine.connect() as conn:
-            conn.execute(self.table_1.insert({"id": 1234, "foo": 42}))
-            conn.execute(self.table_2.insert({"id": 4321, "foo_id": 1234}))
+            conn.execute(self.table_1.insert().values(id=1234, foo=42))
+            conn.execute(self.table_2.insert().values(id=4321, foo_id=1234))
         matched = self.assertRaises(
             exception.DBReferenceError,
             self.engine.execute,
@@ -522,14 +534,16 @@ class TestReferenceErrorSQLite(_SQLAExceptionMatcher, test_base._DbTestCase):
         self.assertIsNone(matched.key_table)
 
 
-class TestReferenceErrorPostgreSQL(TestReferenceErrorSQLite,
-                                   test_base._PostgreSQLOpportunisticTestCase):
+class TestReferenceErrorPostgreSQL(
+    TestReferenceErrorSQLite,
+    db_test_base._PostgreSQLOpportunisticTestCase,
+):
     def test_raise(self):
         params = {'id': 1, 'foo_id': 2}
         matched = self.assertRaises(
             exception.DBReferenceError,
             self.engine.execute,
-            self.table_2.insert(params)
+            self.table_2.insert().values(**params)
         )
         self.assertInnerException(
             matched,
@@ -549,8 +563,8 @@ class TestReferenceErrorPostgreSQL(TestReferenceErrorSQLite,
 
     def test_raise_delete(self):
         with self.engine.connect() as conn:
-            conn.execute(self.table_1.insert({"id": 1234, "foo": 42}))
-            conn.execute(self.table_2.insert({"id": 4321, "foo_id": 1234}))
+            conn.execute(self.table_1.insert().values(id=1234, foo=42))
+            conn.execute(self.table_2.insert().values(id=4321, foo_id=1234))
         matched = self.assertRaises(
             exception.DBReferenceError,
             self.engine.execute,
@@ -573,13 +587,15 @@ class TestReferenceErrorPostgreSQL(TestReferenceErrorSQLite,
         self.assertEqual("resource_entity", matched.key_table)
 
 
-class TestReferenceErrorMySQL(TestReferenceErrorSQLite,
-                              test_base._MySQLOpportunisticTestCase):
+class TestReferenceErrorMySQL(
+    TestReferenceErrorSQLite,
+    db_test_base._MySQLOpportunisticTestCase,
+):
     def test_raise(self):
         matched = self.assertRaises(
             exception.DBReferenceError,
             self.engine.execute,
-            self.table_2.insert({'id': 1, 'foo_id': 2})
+            self.table_2.insert().values(id=1, foo_id=2)
         )
 
         # NOTE(jd) Cannot check precisely with assertInnerException since MySQL
@@ -597,12 +613,12 @@ class TestReferenceErrorMySQL(TestReferenceErrorSQLite,
             conn.detach()  # will not be returned to the pool when closed
 
             # this is incompatible with some internals of the engine
-            conn.execute("SET SESSION sql_mode = 'ANSI';")
+            conn.execute(sql.text("SET SESSION sql_mode = 'ANSI';"))
 
             matched = self.assertRaises(
                 exception.DBReferenceError,
                 conn.execute,
-                self.table_2.insert({'id': 1, 'foo_id': 2})
+                self.table_2.insert().values(id=1, foo_id=2)
             )
 
         # NOTE(jd) Cannot check precisely with assertInnerException since MySQL
@@ -617,8 +633,8 @@ class TestReferenceErrorMySQL(TestReferenceErrorSQLite,
 
     def test_raise_delete(self):
         with self.engine.connect() as conn:
-            conn.execute(self.table_1.insert({"id": 1234, "foo": 42}))
-            conn.execute(self.table_2.insert({"id": 4321, "foo_id": 1234}))
+            conn.execute(self.table_1.insert().values(id=1234, foo=42))
+            conn.execute(self.table_2.insert().values(id=4321, foo_id=1234))
         matched = self.assertRaises(
             exception.DBReferenceError,
             self.engine.execute,
@@ -635,7 +651,9 @@ class TestReferenceErrorMySQL(TestReferenceErrorSQLite,
         self.assertEqual("resource_foo", matched.key_table)
 
 
-class TestExceptionCauseMySQLSavepoint(test_base._MySQLOpportunisticTestCase):
+class TestExceptionCauseMySQLSavepoint(
+    db_test_base._MySQLOpportunisticTestCase,
+):
     def setUp(self):
         super(TestExceptionCauseMySQLSavepoint, self).setUp()
 
@@ -661,7 +679,7 @@ class TestExceptionCauseMySQLSavepoint(test_base._MySQLOpportunisticTestCase):
             with session.begin():
                 try:
                     with session.begin_nested():
-                        session.execute("rollback")
+                        session.execute(sql.text("rollback"))
                         session.add(self.A(id=1))
                 # outermost is the failed SAVEPOINT rollback
                 # from the "with session.begin_nested()"
@@ -689,7 +707,7 @@ class TestExceptionCauseMySQLSavepoint(test_base._MySQLOpportunisticTestCase):
 
         session.begin()
         try:
-            session.execute("select 1")
+            session.execute(sql.text("select 1"))
 
             # close underying DB connection
             session.connection().connection.connection.close()
@@ -699,7 +717,7 @@ class TestExceptionCauseMySQLSavepoint(test_base._MySQLOpportunisticTestCase):
             # session.execute("kill connection %s" % conn_id)
 
             # try using it, will raise an error
-            session.execute("select 1")
+            session.execute(sql.text("select 1"))
         except exception.DBConnectionError:
             # issue being tested is that this session.rollback()
             # does not itself try to re-connect and raise another
@@ -714,7 +732,7 @@ class TestExceptionCauseMySQLSavepoint(test_base._MySQLOpportunisticTestCase):
         session.begin()
         try:
             session.begin_nested()
-            session.execute("select 1")
+            session.execute(sql.text("select 1"))
 
             # close underying DB connection
             session.connection().connection.connection.close()
@@ -724,7 +742,7 @@ class TestExceptionCauseMySQLSavepoint(test_base._MySQLOpportunisticTestCase):
             # session.execute("kill connection %s" % conn_id)
 
             # try using it, will raise an error
-            session.execute("select 1")
+            session.execute(sql.text("select 1"))
         except exception.DBConnectionError:
             # issue being tested is that this session.rollback()
             # does not itself try to re-connect and raise another
@@ -881,28 +899,6 @@ class TestDuplicate(TestsExceptionFilter):
             exception.DBError
         )
 
-    def test_ibm_db_sa(self):
-        self._run_dupe_constraint_test(
-            'ibm_db_sa',
-            'SQL0803N  One or more values in the INSERT statement, UPDATE '
-            'statement, or foreign key update caused by a DELETE statement are'
-            ' not valid because the primary key, unique constraint or unique '
-            'index identified by "2" constrains table "NOVA.KEY_PAIRS" from '
-            'having duplicate values for the index key.',
-            expected_columns=[]
-        )
-
-    def test_ibm_db_sa_notadupe(self):
-        self._not_dupe_constraint_test(
-            'ibm_db_sa',
-            'ALTER TABLE instance_types ADD CONSTRAINT '
-            'uniq_name_x_deleted UNIQUE (name, deleted)',
-            'SQL0542N  The column named "NAME" cannot be a column of a '
-            'primary key or unique key constraint because it can contain null '
-            'values.',
-            exception.DBError
-        )
-
 
 class TestDeadlock(TestsExceptionFilter):
     statement = ('SELECT quota_usages.created_at AS '
@@ -1004,25 +1000,6 @@ class TestDeadlock(TestsExceptionFilter):
             orig_exception_cls=self.TransactionRollbackError
         )
 
-    def test_ibm_db_sa_deadlock(self):
-        self._run_deadlock_detect_test(
-            "ibm_db_sa",
-            "SQL0911N The current transaction has been "
-            "rolled back because of a deadlock or timeout",
-            # use the lowest class b.c. I don't know what actual error
-            # class DB2's driver would raise for this
-            orig_exception_cls=self.Error
-        )
-
-    def test_ibm_db_sa_not_deadlock(self):
-        self._not_deadlock_test(
-            "ibm_db_sa",
-            "SQL01234B Some other error.",
-            exception.DBError,
-            "Error",
-            orig_exception_cls=self.Error
-        )
-
 
 class TestDataError(TestsExceptionFilter):
     def _run_bad_data_test(self, dialect_name, message, error_class):
@@ -1052,7 +1029,7 @@ class TestDataError(TestsExceptionFilter):
                                 self.DataError)
 
 
-class IntegrationTest(test_base._DbTestCase):
+class IntegrationTest(db_test_base._DbTestCase):
     """Test an actual error-raising round trips against the database."""
 
     def setUp(self):
@@ -1189,7 +1166,7 @@ class TestDBDisconnected(TestsExceptionFilter):
         with self._fixture(dialect_name, exc_obj, 1, is_disconnect):
             conn = self.engine.connect()
             with conn.begin():
-                self.assertEqual(1, conn.scalar(sqla.select([1])))
+                self.assertEqual(1, conn.scalar(sqla.select(1)))
                 self.assertFalse(conn.closed)
                 self.assertFalse(conn.invalidated)
                 self.assertTrue(conn.in_transaction())
@@ -1202,7 +1179,7 @@ class TestDBDisconnected(TestsExceptionFilter):
 
         # test implicit execution
         with self._fixture(dialect_name, exc_obj, 1):
-            self.assertEqual(1, self.engine.scalar(sqla.select([1])))
+            self.assertEqual(1, self.engine.scalar(sqla.select(1)))
 
     def test_mariadb_error_1927(self):
         for code in [1927]:
@@ -1256,21 +1233,6 @@ class TestDBDisconnected(TestsExceptionFilter):
             is_disconnect=False
         )
 
-    def test_db2_ping_listener_disconnected(self):
-        self._test_ping_listener_disconnected(
-            "ibm_db_sa",
-            self.OperationalError(
-                'SQL30081N: DB2 Server connection is no longer active')
-        )
-
-    def test_db2_ping_listener_disconnected_regex_only(self):
-        self._test_ping_listener_disconnected(
-            "ibm_db_sa",
-            self.OperationalError(
-                'SQL30081N: DB2 Server connection is no longer active'),
-            is_disconnect=False
-        )
-
     def test_postgresql_ping_listener_disconnected(self):
         self._test_ping_listener_disconnected(
             "postgresql",
@@ -1325,7 +1287,7 @@ class TestDBConnectRetry(TestsExceptionFilter):
             2, -1
         )
         # conn is good
-        self.assertEqual(1, conn.scalar(sqla.select([1])))
+        self.assertEqual(1, conn.scalar(sqla.select(1)))
 
     def test_connect_retry_past_failure(self):
         conn = self._run_test(
@@ -1334,7 +1296,7 @@ class TestDBConnectRetry(TestsExceptionFilter):
             2, 3
         )
         # conn is good
-        self.assertEqual(1, conn.scalar(sqla.select([1])))
+        self.assertEqual(1, conn.scalar(sqla.select(1)))
 
     def test_connect_retry_not_candidate_exception(self):
         self.assertRaises(
@@ -1355,24 +1317,6 @@ class TestDBConnectRetry(TestsExceptionFilter):
             3, 2
         )
 
-    def test_db2_error_positive(self):
-        conn = self._run_test(
-            "ibm_db_sa",
-            self.OperationalError("blah blah -30081 blah blah"),
-            2, -1
-        )
-        # conn is good
-        self.assertEqual(1, conn.scalar(sqla.select([1])))
-
-    def test_db2_error_negative(self):
-        self.assertRaises(
-            sqla.exc.OperationalError,
-            self._run_test,
-            "ibm_db_sa",
-            self.OperationalError("blah blah -39981 blah blah"),
-            2, 3
-        )
-
 
 class TestDBConnectPingWrapping(TestsExceptionFilter):
 
@@ -1419,7 +1363,7 @@ class TestDBConnectPingWrapping(TestsExceptionFilter):
             self, dialect_name, exc_obj, is_disconnect=True):
         with self._fixture(dialect_name, exc_obj, 3, is_disconnect):
             conn = self.engine.connect()
-            self.assertEqual(1, conn.scalar(sqla.select([1])))
+            self.assertEqual(1, conn.scalar(sqla.select(1)))
             conn.close()
 
         with self._fixture(dialect_name, exc_obj, 1, is_disconnect):
