@@ -23,12 +23,12 @@ from unittest import mock
 
 import fixtures
 from oslo_config import cfg
-from oslotest import base as oslo_test
 import sqlalchemy
+from sqlalchemy import sql
 from sqlalchemy import Column, MetaData, Table
 from sqlalchemy.engine import url
 from sqlalchemy import Integer, String
-from sqlalchemy.ext.declarative import declarative_base
+from sqlalchemy.orm import declarative_base
 
 from oslo_db import exception
 from oslo_db import options as db_options
@@ -36,7 +36,8 @@ from oslo_db.sqlalchemy import enginefacade
 from oslo_db.sqlalchemy import engines
 from oslo_db.sqlalchemy import models
 from oslo_db.sqlalchemy import session
-from oslo_db.tests.sqlalchemy import base as test_base
+from oslo_db.tests import base as test_base
+from oslo_db.tests.sqlalchemy import base as db_test_base
 
 
 BASE = declarative_base()
@@ -51,22 +52,21 @@ class RegexpTable(BASE, models.ModelBase):
     bar = Column(String(255))
 
 
-class RegexpFilterTestCase(test_base._DbTestCase):
+class RegexpFilterTestCase(db_test_base._DbTestCase):
 
     def setUp(self):
         super(RegexpFilterTestCase, self).setUp()
         meta = MetaData()
-        meta.bind = self.engine
         test_table = Table(_REGEXP_TABLE_NAME, meta,
                            Column('id', Integer, primary_key=True,
                                   nullable=False),
                            Column('bar', String(255)))
-        test_table.create()
-        self.addCleanup(test_table.drop)
+        test_table.create(self.engine)
+        self.addCleanup(test_table.drop, self.engine)
 
     def _test_regexp_filter(self, regexp, expected):
-        with enginefacade.writer.using(test_base.context):
-            _session = test_base.context.session
+        with enginefacade.writer.using(db_test_base.context):
+            _session = db_test_base.context.session
             for i in ['10', '20', '♥']:
                 tbl = RegexpTable()
                 tbl.update({'bar': i})
@@ -89,7 +89,7 @@ class RegexpFilterTestCase(test_base._DbTestCase):
         self._test_regexp_filter('♦', [])
 
 
-class SQLiteSavepointTest(test_base._DbTestCase):
+class SQLiteSavepointTest(db_test_base._DbTestCase):
     def setUp(self):
         super(SQLiteSavepointTest, self).setUp()
         meta = MetaData()
@@ -121,7 +121,7 @@ class SQLiteSavepointTest(test_base._DbTestCase):
                 0,
                 conn.scalar(
                     sqlalchemy.select(
-                        [sqlalchemy.func.count(self.test_table.c.id)],
+                        sqlalchemy.func.count(self.test_table.c.id),
                     ).select_from(self.test_table)
                 )
             )
@@ -202,23 +202,7 @@ class ProgrammingError(Exception):
     pass
 
 
-class FakeDB2Engine(object):
-
-    class Dialect(object):
-
-        def is_disconnect(self, e, *args):
-            expected_error = ('SQL30081N: DB2 Server connection is no longer '
-                              'active')
-            return (str(e) == expected_error)
-
-    dialect = Dialect()
-    name = 'ibm_db_sa'
-
-    def dispose(self):
-        pass
-
-
-class QueryParamTest(test_base.DbTestCase):
+class QueryParamTest(db_test_base.DbTestCase):
     def _fixture(self):
         from sqlalchemy import create_engine
 
@@ -301,17 +285,17 @@ class QueryParamTest(test_base.DbTestCase):
         )
 
 
-class MySQLDefaultModeTestCase(test_base._MySQLOpportunisticTestCase):
+class MySQLDefaultModeTestCase(db_test_base._MySQLOpportunisticTestCase):
     def test_default_is_traditional(self):
         with self.engine.connect() as conn:
             sql_mode = conn.execute(
-                "SHOW VARIABLES LIKE 'sql_mode'"
+                sql.text("SHOW VARIABLES LIKE 'sql_mode'")
             ).first()[1]
 
         self.assertIn("TRADITIONAL", sql_mode)
 
 
-class MySQLModeTestCase(test_base._MySQLOpportunisticTestCase):
+class MySQLModeTestCase(db_test_base._MySQLOpportunisticTestCase):
 
     def __init__(self, *args, **kwargs):
         super(MySQLModeTestCase, self).__init__(*args, **kwargs)
@@ -380,7 +364,7 @@ class MySQLTraditionalModeTestCase(MySQLStrictAllTablesModeTestCase):
         self.mysql_mode = 'TRADITIONAL'
 
 
-class EngineFacadeTestCase(oslo_test.BaseTestCase):
+class EngineFacadeTestCase(test_base.BaseTestCase):
     def setUp(self):
         super(EngineFacadeTestCase, self).setUp()
 
@@ -486,7 +470,7 @@ class EngineFacadeTestCase(oslo_test.BaseTestCase):
         self.assertEqual(master_path, str(slave_session.bind.url))
 
 
-class SQLiteConnectTest(oslo_test.BaseTestCase):
+class SQLiteConnectTest(test_base.BaseTestCase):
 
     def _fixture(self, **kw):
         return session.create_engine("sqlite://", **kw)
@@ -495,14 +479,14 @@ class SQLiteConnectTest(oslo_test.BaseTestCase):
         engine = self._fixture(sqlite_fk=True)
         self.assertEqual(
             1,
-            engine.scalar("pragma foreign_keys")
+            engine.scalar(sql.text('pragma foreign_keys'))
         )
 
         engine = self._fixture(sqlite_fk=False)
 
         self.assertEqual(
             0,
-            engine.scalar("pragma foreign_keys")
+            engine.scalar(sql.text("pragma foreign_keys"))
         )
 
     def test_sqlite_synchronous_listener(self):
@@ -512,24 +496,26 @@ class SQLiteConnectTest(oslo_test.BaseTestCase):
         # http://www.sqlite.org/pragma.html#pragma_synchronous
         self.assertEqual(
             2,
-            engine.scalar("pragma synchronous")
+            engine.scalar(sql.text('pragma synchronous'))
         )
 
         engine = self._fixture(sqlite_synchronous=False)
 
         self.assertEqual(
             0,
-            engine.scalar("pragma synchronous")
+            engine.scalar(sql.text('pragma synchronous'))
         )
 
 
-class MysqlConnectTest(test_base._MySQLOpportunisticTestCase):
+class MysqlConnectTest(db_test_base._MySQLOpportunisticTestCase):
 
     def _fixture(self, sql_mode):
         return session.create_engine(self.engine.url, mysql_sql_mode=sql_mode)
 
     def _assert_sql_mode(self, engine, sql_mode_present, sql_mode_non_present):
-        mode = engine.execute("SHOW VARIABLES LIKE 'sql_mode'").fetchone()[1]
+        mode = engine.execute(
+            sql.text("SHOW VARIABLES LIKE 'sql_mode'")
+        ).fetchone()[1]
         self.assertIn(
             sql_mode_present, mode
         )
@@ -554,7 +540,8 @@ class MysqlConnectTest(test_base._MySQLOpportunisticTestCase):
         # we get what is configured for the MySQL database, as opposed
         # to what our own session.create_engine() has set it to.
         expected = self.engine.execute(
-            "SELECT @@GLOBAL.sql_mode").scalar()
+            sql.text("SELECT @@GLOBAL.sql_mode")
+        ).scalar()
 
         engine = self._fixture(sql_mode=None)
         self._assert_sql_mode(engine, expected, None)
@@ -607,7 +594,8 @@ class MysqlConnectTest(test_base._MySQLOpportunisticTestCase):
         engine = self._fixture(sql_mode='TRADITIONAL')
 
         actual_mode = engine.execute(
-            "SHOW VARIABLES LIKE 'sql_mode'").fetchone()[1]
+            sql.text("SHOW VARIABLES LIKE 'sql_mode'")
+        ).fetchone()[1]
 
         self.assertIn('MySQL server mode set to %s' % actual_mode,
                       log.output)
@@ -643,7 +631,7 @@ class MysqlConnectTest(test_base._MySQLOpportunisticTestCase):
                          log.output)
 
 
-class CreateEngineTest(oslo_test.BaseTestCase):
+class CreateEngineTest(test_base.BaseTestCase):
     """Test that dialect-specific arguments/ listeners are set up correctly.
 
     """
@@ -797,7 +785,7 @@ class CreateEngineTest(oslo_test.BaseTestCase):
         )
 
 
-class ProcessGuardTest(test_base._DbTestCase):
+class ProcessGuardTest(db_test_base._DbTestCase):
     def test_process_guard(self):
         self.engine.dispose()
 
@@ -825,7 +813,7 @@ class ProcessGuardTest(test_base._DbTestCase):
         self.assertEqual(new_dbapi_id, newer_dbapi_id)
 
 
-class PatchStacktraceTest(test_base._DbTestCase):
+class PatchStacktraceTest(db_test_base._DbTestCase):
 
     def test_trace(self):
         engine = self.engine
@@ -848,7 +836,7 @@ class PatchStacktraceTest(test_base._DbTestCase):
             with mock.patch.object(engine.dialect, "do_execute") as mock_exec:
 
                 mock_exec.side_effect = orig_do_exec
-                conn.execute("select 1;")
+                conn.execute(sql.text("select 1"))
 
             call = mock_exec.mock_calls[0]
 
