@@ -17,22 +17,21 @@ from unittest import mock
 from urllib import parse
 
 import fixtures
-from oslotest import base as test_base
 import sqlalchemy
 from sqlalchemy.dialects import mysql
-from sqlalchemy import Boolean, Index, Integer, DateTime, String, SmallInteger
+from sqlalchemy import Boolean, Index, Integer, DateTime, String
 from sqlalchemy import CheckConstraint
 from sqlalchemy import MetaData, Table, Column
 from sqlalchemy import ForeignKey, ForeignKeyConstraint
 from sqlalchemy.dialects.postgresql import psycopg2
-from sqlalchemy.engine import reflection
 from sqlalchemy.engine import url as sa_url
 from sqlalchemy.exc import OperationalError
-from sqlalchemy.ext.declarative import declarative_base
 from sqlalchemy.ext.hybrid import hybrid_property
+from sqlalchemy.orm import declarative_base
 from sqlalchemy.orm import mapper
 from sqlalchemy.orm import Session
 from sqlalchemy import PrimaryKeyConstraint
+from sqlalchemy import sql
 from sqlalchemy.sql.expression import cast
 from sqlalchemy.sql import select
 from sqlalchemy.types import UserDefinedType
@@ -42,9 +41,8 @@ from oslo_db.sqlalchemy import models
 from oslo_db.sqlalchemy import provision
 from oslo_db.sqlalchemy import session
 from oslo_db.sqlalchemy import utils
+from oslo_db.tests import base as test_base
 from oslo_db.tests.sqlalchemy import base as db_test_base
-from oslo_db.tests import utils as test_utils
-
 
 Base = declarative_base()
 
@@ -632,7 +630,7 @@ class TestPaginateQueryActualSQL(test_base.BaseTestCase):
                                  marker=FakeTable(user_id='hello',
                                                   enabled=False))
         expected_core_sql = (
-            select([FakeTable]).
+            select(FakeTable).
             order_by(sqlalchemy.asc(FakeTable.enabled)).
             where(cast(FakeTable.enabled, Integer) > 0).
             limit(5)
@@ -651,7 +649,7 @@ class TestPaginateQueryActualSQL(test_base.BaseTestCase):
             ['user_id', 'some_hybrid'],
             sort_dirs=['asc', 'desc'])
         expected_core_sql = (
-            select([FakeTable]).
+            select(FakeTable).
             order_by(sqlalchemy.asc(FakeTable.user_id)).
             order_by(sqlalchemy.desc(FakeTable.some_hybrid)).
             limit(5)
@@ -669,9 +667,11 @@ class TestMigrationUtils(db_test_base._DbTestCase):
 
     def setUp(self):
         super(TestMigrationUtils, self).setUp()
-        self.meta = MetaData(bind=self.engine)
+        self.meta = MetaData()
         self.conn = self.engine.connect()
-        self.addCleanup(self.meta.drop_all)
+
+        # self.conn would be better here but does not work right now
+        self.addCleanup(self.meta.drop_all, self.engine)
         self.addCleanup(self.conn.close)
 
     def _populate_db_for_drop_duplicate_entries(self, engine, meta,
@@ -698,7 +698,7 @@ class TestMigrationUtils(db_test_base._DbTestCase):
                            Column('deleted_at', DateTime),
                            Column('updated_at', DateTime))
 
-        test_table.create()
+        test_table.create(engine)
         engine.execute(test_table.insert(), values)
         return test_table, values
 
@@ -719,8 +719,10 @@ class TestMigrationUtils(db_test_base._DbTestCase):
             uniq_values.add(uniq_value)
             expected_ids.append(value['id'])
 
-        real_ids = [row[0] for row in
-                    self.engine.execute(select([test_table.c.id])).fetchall()]
+        real_ids = [
+            row[0] for row in
+            self.engine.execute(select(test_table.c.id)).fetchall()
+        ]
 
         self.assertEqual(len(expected_ids), len(real_ids))
         for id_ in expected_ids:
@@ -732,7 +734,6 @@ class TestMigrationUtils(db_test_base._DbTestCase):
         in_file_engine = session.EngineFacade(
             'sqlite:///%s' % tmp_db_file).get_engine()
         meta = MetaData()
-        meta.bind = in_file_engine
         test_table, values = self._populate_db_for_drop_duplicate_entries(
             in_file_engine, meta, table_name)
         utils.drop_old_duplicate_entries_from_table(
@@ -794,11 +795,11 @@ class TestMigrationUtils(db_test_base._DbTestCase):
                       Column('b', String(255)),
                       Column('deleted', Boolean),
                       *index_instances)
-        table.create()
+        table.create(self.engine)
         utils.change_deleted_column_type_to_id_type(self.engine, table_name)
         utils.change_deleted_column_type_to_boolean(self.engine, table_name)
 
-        insp = reflection.Inspector.from_engine(self.engine)
+        insp = sqlalchemy.inspect(self.engine)
         real_indexes = insp.get_indexes(table_name)
         self.assertEqual(3, len(real_indexes))
         for index in real_indexes:
@@ -812,7 +813,7 @@ class TestMigrationUtils(db_test_base._DbTestCase):
         table = Table(table_name, self.meta,
                       Column('id', Integer, primary_key=True),
                       Column('deleted', Boolean))
-        table.create()
+        table.create(self.engine)
         utils.change_deleted_column_type_to_id_type(self.engine, table_name)
 
         table = utils.get_table(self.engine, table_name)
@@ -823,7 +824,7 @@ class TestMigrationUtils(db_test_base._DbTestCase):
         table = Table(table_name, self.meta,
                       Column('id', String(255), primary_key=True),
                       Column('deleted', Boolean))
-        table.create()
+        table.create(self.engine)
         utils.change_deleted_column_type_to_id_type(self.engine, table_name)
 
         table = utils.get_table(self.engine, table_name)
@@ -836,7 +837,7 @@ class TestMigrationUtils(db_test_base._DbTestCase):
                       Column('id', Integer, primary_key=True),
                       Column('foo', CustomType),
                       Column('deleted', Boolean))
-        table.create()
+        table.create(self.engine)
 
         fooColumn = Column('foo', CustomType())
         utils.change_deleted_column_type_to_id_type(self.engine, table_name,
@@ -847,13 +848,12 @@ class TestMigrationUtils(db_test_base._DbTestCase):
         self.assertIsInstance(table.c.deleted.type, Integer)
 
     def test_change_deleted_column_type_to_boolean(self):
-        expected_types = {'mysql': mysql.TINYINT,
-                          'ibm_db_sa': SmallInteger}
+        expected_types = {'mysql': mysql.TINYINT}
         table_name = 'abc'
         table = Table(table_name, self.meta,
                       Column('id', Integer, primary_key=True),
                       Column('deleted', Integer))
-        table.create()
+        table.create(self.engine)
 
         utils.change_deleted_column_type_to_boolean(self.engine, table_name)
 
@@ -862,22 +862,21 @@ class TestMigrationUtils(db_test_base._DbTestCase):
                               expected_types.get(self.engine.name, Boolean))
 
     def test_change_deleted_column_type_to_boolean_with_fc(self):
-        expected_types = {'mysql': mysql.TINYINT,
-                          'ibm_db_sa': SmallInteger}
+        expected_types = {'mysql': mysql.TINYINT}
         table_name_1 = 'abc'
         table_name_2 = 'bcd'
 
         table_1 = Table(table_name_1, self.meta,
                         Column('id', Integer, primary_key=True),
                         Column('deleted', Integer))
-        table_1.create()
+        table_1.create(self.engine)
 
         table_2 = Table(table_name_2, self.meta,
                         Column('id', Integer, primary_key=True),
                         Column('foreign_id', Integer,
                                ForeignKey('%s.id' % table_name_1)),
                         Column('deleted', Integer))
-        table_2.create()
+        table_2.create(self.engine)
 
         utils.change_deleted_column_type_to_boolean(self.engine, table_name_2)
 
@@ -892,7 +891,7 @@ class TestMigrationUtils(db_test_base._DbTestCase):
                       Column('id', Integer, primary_key=True),
                       Column('foo', CustomType),
                       Column('deleted', Integer))
-        table.create()
+        table.create(self.engine)
 
         fooColumn = Column('foo', CustomType())
         utils.change_deleted_column_type_to_boolean(self.engine, table_name,
@@ -924,25 +923,25 @@ class TestMigrationUtils(db_test_base._DbTestCase):
         table = Table(table_name, self.meta,
                       Column('id', Integer, primary_key=True),
                       Column('deleted', Boolean))
-        table.create()
+        table.create(self.engine)
 
         utils._change_deleted_column_type_to_id_type_sqlite(self.engine,
                                                             table_name)
-        table = Table(table_name, self.meta, autoload=True)
+        table = Table(table_name, self.meta, autoload_with=self.engine)
         # NOTE(I159): if the CHECK constraint has been dropped (expected
         # behavior), any integer value can be inserted, otherwise only 1 or 0.
         # NOTE(zzzeek): SQLAlchemy 1.2 Boolean type will disallow non 1/0
         # value here, 1.1 also coerces to "1/0" so use raw SQL to test the
         # constraint
         with self.engine.connect() as conn:
-            conn.execute(
+            conn.exec_driver_sql(
                 "INSERT INTO abc (deleted) VALUES (?)",
-                (10, )
+                (10, ),
             )
 
             self.assertEqual(
                 10,
-                conn.scalar("SELECT deleted FROM abc")
+                conn.scalar(sql.text("SELECT deleted FROM abc")),
             )
 
     def test_get_foreign_key_constraint_name(self):
@@ -957,7 +956,7 @@ class TestMigrationUtils(db_test_base._DbTestCase):
                                              name='table_name_2_fk1'),
                         Column('deleted', Integer))
 
-        self.meta.create_all(tables=[table_1, table_2])
+        self.meta.create_all(self.engine, tables=[table_1, table_2])
         fkc = utils.get_foreign_key_constraint_name(self.engine,
                                                     'table_name_2',
                                                     'foreign_id')
@@ -987,7 +986,7 @@ class TestMigrationUtils(db_test_base._DbTestCase):
                 ['key', 'archive_id'], ['b.key', 'b.archive_id'],
                 name="some_composite_fk")
         )
-        self.meta.create_all(tables=[a, b, c])
+        self.meta.create_all(self.engine, tables=[a, b, c])
 
         def get_fk_entries():
             inspector = sqlalchemy.inspect(self.engine)
@@ -1075,7 +1074,7 @@ class MySQLTestMigrations(TestMigrationUtils,
     pass
 
 
-class TestConnectionUtils(test_utils.BaseTestCase):
+class TestConnectionUtils(test_base.BaseTestCase):
 
     def setUp(self):
         super(TestConnectionUtils, self).setUp()
@@ -1260,15 +1259,15 @@ class TestModelQuery(test_base.BaseTestCase):
 class TestUtils(db_test_base._DbTestCase):
     def setUp(self):
         super(TestUtils, self).setUp()
-        meta = MetaData(bind=self.engine)
+        meta = MetaData()
         self.test_table = Table(
             'test_table',
             meta,
             Column('a', Integer),
             Column('b', Integer)
         )
-        self.test_table.create()
-        self.addCleanup(meta.drop_all)
+        self.test_table.create(self.engine)
+        self.addCleanup(meta.drop_all, self.engine)
 
     def test_get_indexes(self):
         Index('index_a', self.test_table.c.a).create(self.engine)
@@ -1605,7 +1604,6 @@ class TestDialectFunctionDispatcher(test_base.BaseTestCase):
 
         dispatcher("postgresql+pyodbc://", 1)
         dispatcher("mysql+pymysql://", 2)
-        dispatcher("ibm_db_sa+db2://", 3)
         dispatcher("postgresql+psycopg2://", 4)
         dispatcher("postgresql://", 5)
 
@@ -1620,7 +1618,6 @@ class TestDialectFunctionDispatcher(test_base.BaseTestCase):
                 mock.call.mysql_pymysql('mysql+pymysql://', 2),
                 mock.call.mysql('mysql+pymysql://', 2),
                 mock.call.default('mysql+pymysql://', 2),
-                mock.call.default('ibm_db_sa+db2://', 3),
                 mock.call.postgresql_psycopg2('postgresql+psycopg2://', 4),
                 mock.call.postgresql('postgresql+psycopg2://', 4),
                 mock.call.default('postgresql+psycopg2://', 4),
@@ -1650,41 +1647,43 @@ class TestDialectFunctionDispatcher(test_base.BaseTestCase):
 class TestGetInnoDBTables(db_test_base._MySQLOpportunisticTestCase):
 
     def test_all_tables_use_innodb(self):
-        self.engine.execute("CREATE TABLE customers "
-                            "(a INT, b CHAR (20), INDEX (a)) ENGINE=InnoDB")
+        self.engine.execute(
+            sql.text(
+                "CREATE TABLE customers "
+                "(a INT, b CHAR (20), INDEX (a)) ENGINE=InnoDB"))
         self.assertEqual([], utils.get_non_innodb_tables(self.engine))
 
     def test_all_tables_use_innodb_false(self):
-        self.engine.execute("CREATE TABLE employee "
-                            "(i INT) ENGINE=MEMORY")
+        self.engine.execute(
+            sql.text("CREATE TABLE employee (i INT) ENGINE=MEMORY"))
         self.assertEqual(['employee'],
                          utils.get_non_innodb_tables(self.engine))
 
     def test_skip_tables_use_default_value(self):
-        self.engine.execute("CREATE TABLE migrate_version "
-                            "(i INT) ENGINE=MEMORY")
+        self.engine.execute(
+            sql.text("CREATE TABLE migrate_version (i INT) ENGINE=MEMORY"))
         self.assertEqual([],
                          utils.get_non_innodb_tables(self.engine))
 
     def test_skip_tables_use_passed_value(self):
-        self.engine.execute("CREATE TABLE some_table "
-                            "(i INT) ENGINE=MEMORY")
+        self.engine.execute(
+            sql.text("CREATE TABLE some_table (i INT) ENGINE=MEMORY"))
         self.assertEqual([],
                          utils.get_non_innodb_tables(
                              self.engine, skip_tables=('some_table',)))
 
     def test_skip_tables_use_empty_list(self):
-        self.engine.execute("CREATE TABLE some_table_3 "
-                            "(i INT) ENGINE=MEMORY")
+        self.engine.execute(
+            sql.text("CREATE TABLE some_table_3 (i INT) ENGINE=MEMORY"))
         self.assertEqual(['some_table_3'],
                          utils.get_non_innodb_tables(
                          self.engine, skip_tables=()))
 
     def test_skip_tables_use_several_values(self):
-        self.engine.execute("CREATE TABLE some_table_1 "
-                            "(i INT) ENGINE=MEMORY")
-        self.engine.execute("CREATE TABLE some_table_2 "
-                            "(i INT) ENGINE=MEMORY")
+        self.engine.execute(
+            sql.text("CREATE TABLE some_table_1 (i INT) ENGINE=MEMORY"))
+        self.engine.execute(
+            sql.text("CREATE TABLE some_table_2 (i INT) ENGINE=MEMORY"))
         self.assertEqual([],
                          utils.get_non_innodb_tables(
                              self.engine,
